@@ -101,10 +101,15 @@ class Mosaic(object):
         # This is only really useful when the image affines had rotations
         # and thus we needed to interpolate
         if mask_data is not None:
-            self.anat_img._data[~mask_data] = 0
             if stat is not None:
                 self.stat_img._data[~mask_data] = 0
 
+            # Use an implicit/explicit mask to zero out very dim voxels
+            # This helps deal with the interpolation error for non-MNI
+            # data which otherwise causes a weird ring around the brain
+            thresh = np.percentile(self.anat_data[mask_data], 98) * .05
+            self.anat_img._data[self.anat_data < thresh] = 0
+
         # Find a field of view with nonzero anat voxels
         anat_fov = self.anat_img.get_data() > 1e-5
 
@@ -221,7 +226,10 @@ class Mosaic(object):
             vmin = thresh
         if vmax is None:
             calc_data = stat_data[np.abs(stat_data) > thresh]
-            vmax = np.percentile(np.abs(calc_data), vmax_perc)
+            if calc_data.any():
+                vmax = np.percentile(np.abs(calc_data), vmax_perc)
+            else:
+                vmax = vmin * 2
 
         pos_cmap = self._get_cmap(pos_cmap)
 
@@ -286,7 +294,10 @@ class Mosaic(object):
         if vmin is None:
             vmin = np.percentile(stat_data[fov], vmin_perc)
         if vmax is None:
-            vmax = np.percentile(stat_data[fov], vmax_perc)
+            if stat_data.any():
+                vmax = np.percentile(stat_data[fov], vmax_perc)
+            else:
+                vmax = vmin * 2
         if center:
             vabs = max(np.abs(vmin), vmax)
             vmin, vmax = -vabs, vabs
