@@ -136,7 +136,7 @@ def test_bootstrap_units():
 @raises(ValueError)
 def test_bootstrap_arglength():
     """Test that different length args raise ValueError."""
-    stat.bootstrap(range(5), range(10))
+    stat.bootstrap(np.arange(5), np.arange(10))
 
 
 @raises(TypeError)
@@ -461,8 +461,8 @@ def test_transition_probabilities():
     a = rs.rand(100) < .5
     a = np.where(a, "foo", "bar")
     out = stat.transition_probabilities(a)
-    npt.assert_equal(out.columns.tolist(), ["bar", "foo"])
-    npt.assert_equal(out.columns, out.index)
+    npt.assert_array_equal(out.columns.tolist(), ["bar", "foo"])
+    npt.assert_array_equal(out.columns, out.index)
 
 
 def test_gamma_hrf_fit_direct():
